# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v2/report/status.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='v2/report/status.proto',
    package='',
    serialized_pb=_b(
        '\n\x16v2/report/status.proto\"i\n\x06status\x12\x0f\n\x07scan_id\x18\x01 \x02(\x05\x12%\n\nattributes\x18\x02 \x03(\x0b\x32\x11.status.attribute\x1a\'\n\tattribute\x12\x0b\n\x03key\x18\x01 \x02(\t\x12\r\n\x05value\x18\x02 \x02(\t')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_STATUS_ATTRIBUTE = _descriptor.Descriptor(
    name='attribute',
    full_name='status.attribute',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='key', full_name='status.attribute.key', index=0,
            number=1, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='value', full_name='status.attribute.value', index=1,
            number=2, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    options=None,
    is_extendable=False,
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=92,
    serialized_end=131,
)

_STATUS = _descriptor.Descriptor(
    name='status',
    full_name='status',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='scan_id', full_name='status.scan_id', index=0,
            number=1, type=5, cpp_type=1, label=2,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='attributes', full_name='status.attributes', index=1,
            number=2, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
    ],
    extensions=[
    ],
    nested_types=[_STATUS_ATTRIBUTE, ],
    enum_types=[
    ],
    options=None,
    is_extendable=False,
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=26,
    serialized_end=131,
)

_STATUS_ATTRIBUTE.containing_type = _STATUS
_STATUS.fields_by_name['attributes'].message_type = _STATUS_ATTRIBUTE
DESCRIPTOR.message_types_by_name['status'] = _STATUS

status = _reflection.GeneratedProtocolMessageType('status', (_message.Message,), dict(

    attribute=_reflection.GeneratedProtocolMessageType('attribute', (_message.Message,), dict(
        DESCRIPTOR=_STATUS_ATTRIBUTE,
        __module__='v2.report.status_pb2'
        # @@protoc_insertion_point(class_scope:status.attribute)
    ))
    ,
    DESCRIPTOR=_STATUS,
    __module__='v2.report.status_pb2'
    # @@protoc_insertion_point(class_scope:status)
))
_sym_db.RegisterMessage(status)
_sym_db.RegisterMessage(status.attribute)

# @@protoc_insertion_point(module_scope)
