# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: test.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='test.proto',
    package='',
    syntax='proto2',
    serialized_pb=_b(
        '\n\ntest.proto\"5\n\x16link_test_extra_header\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\r\n\x05value\x18\x02 \x02(\t\"/\n\x10link_test_cookie\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\r\n\x05value\x18\x02 \x02(\t\"A\n\x14link_test_form_input\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x02(\t\x12\x0c\n\x04type\x18\x03 \x02(\t\"H\n\x0elink_test_form\x12%\n\x06inputs\x18\x01 \x03(\x0b\x32\x15.link_test_form_input\x12\x0f\n\x07\x65nctype\x18\x02 \x02(\t\"M\n\x0ftest_credential\x12\x0c\n\x04type\x18\x01 \x02(\t\x12\r\n\x05login\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\x12\x0b\n\x03url\x18\x04 \x01(\t\"\x95\x02\n\x04test\x12\x0f\n\x07scan_id\x18\x01 \x02(\x05\x12\x0f\n\x07link_id\x18\x02 \x01(\x05\x12\x0b\n\x03url\x18\x03 \x02(\t\x12\x0e\n\x06method\x18\x04 \x02(\t\x12\x0e\n\x04\x62ody\x18\x05 \x01(\x0cH\x00\x12\x1f\n\x04\x66orm\x18\x06 \x01(\x0b\x32\x0f.link_test_formH\x00\x12.\n\rextra_headers\x18\x07 \x03(\x0b\x32\x17.link_test_extra_header\x12\"\n\x07\x63ookies\x18\x08 \x03(\x0b\x32\x11.link_test_cookie\x12$\n\ncredential\x18\t \x01(\x0b\x32\x10.test_credential\x12\x15\n\x06parent\x18\n \x01(\x0b\x32\x05.testB\x0c\n\nbody_oneof')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_LINK_TEST_EXTRA_HEADER = _descriptor.Descriptor(
    name='link_test_extra_header',
    full_name='link_test_extra_header',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='name', full_name='link_test_extra_header.name', index=0,
            number=1, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='value', full_name='link_test_extra_header.value', index=1,
            number=2, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    options=None,
    is_extendable=False,
    syntax='proto2',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=14,
    serialized_end=67,
)

_LINK_TEST_COOKIE = _descriptor.Descriptor(
    name='link_test_cookie',
    full_name='link_test_cookie',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='name', full_name='link_test_cookie.name', index=0,
            number=1, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='value', full_name='link_test_cookie.value', index=1,
            number=2, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    options=None,
    is_extendable=False,
    syntax='proto2',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=69,
    serialized_end=116,
)

_LINK_TEST_FORM_INPUT = _descriptor.Descriptor(
    name='link_test_form_input',
    full_name='link_test_form_input',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='name', full_name='link_test_form_input.name', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='value', full_name='link_test_form_input.value', index=1,
            number=2, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='type', full_name='link_test_form_input.type', index=2,
            number=3, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    options=None,
    is_extendable=False,
    syntax='proto2',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=118,
    serialized_end=183,
)

_LINK_TEST_FORM = _descriptor.Descriptor(
    name='link_test_form',
    full_name='link_test_form',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='inputs', full_name='link_test_form.inputs', index=0,
            number=1, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='enctype', full_name='link_test_form.enctype', index=1,
            number=2, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    options=None,
    is_extendable=False,
    syntax='proto2',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=185,
    serialized_end=257,
)

_TEST_CREDENTIAL = _descriptor.Descriptor(
    name='test_credential',
    full_name='test_credential',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='type', full_name='test_credential.type', index=0,
            number=1, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='login', full_name='test_credential.login', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='password', full_name='test_credential.password', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='url', full_name='test_credential.url', index=3,
            number=4, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    options=None,
    is_extendable=False,
    syntax='proto2',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=259,
    serialized_end=336,
)

_TEST = _descriptor.Descriptor(
    name='test',
    full_name='test',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='scan_id', full_name='test.scan_id', index=0,
            number=1, type=5, cpp_type=1, label=2,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='link_id', full_name='test.link_id', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='url', full_name='test.url', index=2,
            number=3, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='method', full_name='test.method', index=3,
            number=4, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='body', full_name='test.body', index=4,
            number=5, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='form', full_name='test.form', index=5,
            number=6, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='extra_headers', full_name='test.extra_headers', index=6,
            number=7, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='cookies', full_name='test.cookies', index=7,
            number=8, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='credential', full_name='test.credential', index=8,
            number=9, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='parent', full_name='test.parent', index=9,
            number=10, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    options=None,
    is_extendable=False,
    syntax='proto2',
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name='body_oneof', full_name='test.body_oneof',
            index=0, containing_type=None, fields=[]),
    ],
    serialized_start=339,
    serialized_end=616,
)

_LINK_TEST_FORM.fields_by_name['inputs'].message_type = _LINK_TEST_FORM_INPUT
_TEST.fields_by_name['form'].message_type = _LINK_TEST_FORM
_TEST.fields_by_name['extra_headers'].message_type = _LINK_TEST_EXTRA_HEADER
_TEST.fields_by_name['cookies'].message_type = _LINK_TEST_COOKIE
_TEST.fields_by_name['credential'].message_type = _TEST_CREDENTIAL
_TEST.fields_by_name['parent'].message_type = _TEST
_TEST.oneofs_by_name['body_oneof'].fields.append(
    _TEST.fields_by_name['body'])
_TEST.fields_by_name['body'].containing_oneof = _TEST.oneofs_by_name['body_oneof']
_TEST.oneofs_by_name['body_oneof'].fields.append(
    _TEST.fields_by_name['form'])
_TEST.fields_by_name['form'].containing_oneof = _TEST.oneofs_by_name['body_oneof']
DESCRIPTOR.message_types_by_name['link_test_extra_header'] = _LINK_TEST_EXTRA_HEADER
DESCRIPTOR.message_types_by_name['link_test_cookie'] = _LINK_TEST_COOKIE
DESCRIPTOR.message_types_by_name['link_test_form_input'] = _LINK_TEST_FORM_INPUT
DESCRIPTOR.message_types_by_name['link_test_form'] = _LINK_TEST_FORM
DESCRIPTOR.message_types_by_name['test_credential'] = _TEST_CREDENTIAL
DESCRIPTOR.message_types_by_name['test'] = _TEST

link_test_extra_header = _reflection.GeneratedProtocolMessageType('link_test_extra_header', (_message.Message,), dict(
    DESCRIPTOR=_LINK_TEST_EXTRA_HEADER,
    __module__='test_pb2'
    # @@protoc_insertion_point(class_scope:link_test_extra_header)
))
_sym_db.RegisterMessage(link_test_extra_header)

link_test_cookie = _reflection.GeneratedProtocolMessageType('link_test_cookie', (_message.Message,), dict(
    DESCRIPTOR=_LINK_TEST_COOKIE,
    __module__='test_pb2'
    # @@protoc_insertion_point(class_scope:link_test_cookie)
))
_sym_db.RegisterMessage(link_test_cookie)

link_test_form_input = _reflection.GeneratedProtocolMessageType('link_test_form_input', (_message.Message,), dict(
    DESCRIPTOR=_LINK_TEST_FORM_INPUT,
    __module__='test_pb2'
    # @@protoc_insertion_point(class_scope:link_test_form_input)
))
_sym_db.RegisterMessage(link_test_form_input)

link_test_form = _reflection.GeneratedProtocolMessageType('link_test_form', (_message.Message,), dict(
    DESCRIPTOR=_LINK_TEST_FORM,
    __module__='test_pb2'
    # @@protoc_insertion_point(class_scope:link_test_form)
))
_sym_db.RegisterMessage(link_test_form)

test_credential = _reflection.GeneratedProtocolMessageType('test_credential', (_message.Message,), dict(
    DESCRIPTOR=_TEST_CREDENTIAL,
    __module__='test_pb2'
    # @@protoc_insertion_point(class_scope:test_credential)
))
_sym_db.RegisterMessage(test_credential)

test = _reflection.GeneratedProtocolMessageType('test', (_message.Message,), dict(
    DESCRIPTOR=_TEST,
    __module__='test_pb2'
    # @@protoc_insertion_point(class_scope:test)
))
_sym_db.RegisterMessage(test)

# @@protoc_insertion_point(module_scope)
